@@ -1,6 +1,6 @@
 import numpy as np
 from numpy import mgrid
-from spotPython.design import designs
+from .designs import designs
 
 
 class factorial(designs):
